@@ -1021,9 +1021,9 @@ static int wp_tdmapi_release(struct inode *inode, struct file *file)
 
 	tdm_api->cfg.rbs_rx_bits=-1;
 	tdm_api->cfg.rbs_tx_bits=-1;
-	
+
 	tdm_api->cfg.rbs_poll=0;
-	
+
 	file->private_data=NULL;
 	
 	wan_spin_unlock(&tdm_api->lock);
@@ -1534,23 +1534,37 @@ int wanpipe_tdm_api_ioctl(wanpipe_tdm_api_dev_t *tdm_api, struct ifreq *ifr)
 		usr_tdm_api.rbs_poll=HZ/usr_tdm_api.rbs_poll;
 		
 		tdm_api->cfg.rbs_poll = usr_tdm_api.rbs_poll;
-		if (card && card->wandev.fe_iface.set_fe_sigctrl){
-                 	card->wandev.fe_iface.set_fe_sigctrl(
+
+		if (card->u.aft.cfg.rbs) {
+			err=0;
+
+		} else if (card && card->wandev.fe_iface.set_fe_sigctrl){
+            err = card->wandev.fe_iface.set_fe_sigctrl(
 					&card->fe,
 					WAN_TE_SIG_POLL,
 					ENABLE_ALL_CHANNELS,
 					WAN_ENABLE);
+			if (err == 0) {
+				card->u.aft.cfg.rbs=1;
+			}
 		}
 		break;
 		
 	case SIOC_WP_TDM_DISABLE_RBS_EVENTS:	
 		tdm_api->cfg.rbs_poll=0;
-		if (card && card->wandev.fe_iface.set_fe_sigctrl){
-                 	card->wandev.fe_iface.set_fe_sigctrl(
-					&card->fe,
-					WAN_TE_SIG_POLL,
-					ENABLE_ALL_CHANNELS,
-					WAN_DISABLE);
+
+		if (card->u.aft.cfg.rbs == 0) {
+			err=0;
+			/* Do nothing */
+		} else if (card && card->wandev.fe_iface.set_fe_sigctrl){
+			err=card->wandev.fe_iface.set_fe_sigctrl(
+				&card->fe,
+				WAN_TE_SIG_POLL,
+				ENABLE_ALL_CHANNELS,
+				WAN_DISABLE);
+			if (err == 0) {
+				card->u.aft.cfg.rbs=0;
+			}
 		}
 		break;
 
